@@ -854,11 +854,12 @@ class Client:
 
         pygame.init()
         pygame.display.set_caption('Client')
+        pygame.mouse.set_cursor(pygame.cursors.arrow)
         os.chdir(os.path.dirname(__file__))
         font_size = 45
         self.font = pygame.font.SysFont('Comic Sans MS', font_size)
         screenstring="localhost:"+self.player.screen_num
-        os.putenv("DISPLAY", screenstring)
+        os.environ["DISPLAY"]=screenstring
         os.environ['SDL_VIDEODRIVER'] = 'x11'
         self.game_window = pygame.display.set_mode(RESOLUTION, pygame.FULLSCREEN)
         # self.game_window = pygame.display.set_mode(RESOLUTION)
